@@ -23,16 +23,16 @@
 class list_test_usage implements pts_option_interface
 {
 	const doc_section = 'Information';
-	const doc_description = "This option will list various details about installed tests and their usage.";
+	const doc_description = 'This option will list various details about installed tests and their usage.';
 
 	public static function run($r)
 	{
 		$installed_tests = pts_tests::installed_tests();
-		pts_client::$display->generic_heading(count($installed_tests) . " Tests Installed");
+		pts_client::$display->generic_heading(count($installed_tests) . ' Tests Installed');
 
 		if(count($installed_tests) > 0)
 		{
-			printf("%-18ls   %-8ls %-13ls %-11ls %-13ls %-10ls\n", "TEST", "VERSION", "INSTALL DATE", "LAST RUN", "AVG RUN-TIME", "TIMES RUN");
+			echo sprintf('%-18ls   %-8ls %-13ls %-11ls %-13ls %-10ls', 'TEST', 'VERSION', 'INSTALL DATE', 'LAST RUN', 'AVG RUN-TIME', 'TIMES RUN') . PHP_EOL;
 			foreach($installed_tests as $identifier)
 			{
 				$test_profile = new pts_test_profile($identifier);
@@ -40,15 +40,14 @@ class list_test_usage implements pts_option_interface
 				if($test_profile != false && $test_profile->test_installation->get_installed_version() != null)
 				{
 					$avg_time = $test_profile->test_installation->get_average_run_time();
-					$avg_time = !empty($avg_time) ? pts_strings::format_time($avg_time, "SECONDS", false) : "N/A";
+					$avg_time = !empty($avg_time) ? pts_strings::format_time($avg_time, 'SECONDS', false) : 'N/A';
 
 					$last_run = $test_profile->test_installation->get_last_run_date();
-					$last_run = $last_run == "0000-00-00" ? "NEVER" : $last_run;
+					$last_run = $last_run == '0000-00-00' ? 'NEVER' : $last_run;
 
-					printf("%-18ls - %-8ls %-13ls %-11ls %-13ls %-10ls\n", $identifier, $test_profile->test_installation->get_installed_version(), $test_profile->test_installation->get_install_date(), $last_run, $avg_time, $test_profile->test_installation->get_run_count());
+					echo sprintf('%-18ls - %-8ls %-13ls %-11ls %-13ls %-10ls', $identifier, $test_profile->test_installation->get_installed_version(), $test_profile->test_installation->get_install_date(), $last_run, $avg_time, $test_profile->test_installation->get_run_count()) . PHP_EOL;
 				}
 			}
-			echo "\n";
 		}
 	}
 }
