@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 	phodevi_gpu.php: The PTS Device Interface object for the graphics processor
 
 	This program is free software; you can redistribute it and/or modify
@@ -55,10 +55,10 @@ class phodevi_gpu extends phodevi_device_interface
 				$property = new phodevi_device_property('gpu_available_modes', phodevi::smart_caching);
 				break;
 			case 'screen-resolution':
-				$property = new phodevi_device_property('gpu_screen_resolution', phodevi::smart_caching);
+				$property = new phodevi_device_property('gpu_screen_resolution', phodevi::std_caching);
 				break;
 			case 'screen-resolution-string':
-				$property = new phodevi_device_property('gpu_screen_resolution_string', phodevi::smart_caching);
+				$property = new phodevi_device_property('gpu_screen_resolution_string', phodevi::std_caching);
 				break;
 		}
 
@@ -100,7 +100,7 @@ class phodevi_gpu extends phodevi_device_interface
 	}
 	public static function gpu_set_resolution($args)
 	{
-		if(count($args) != 2 || phodevi::is_windows() || phodevi::is_macosx())
+		if(count($args) != 2 || phodevi::is_windows() || phodevi::is_macosx() || !pts_client::executable_in_path('xrandr'))
 		{
 			return false;
 		}
@@ -280,6 +280,31 @@ class phodevi_gpu extends phodevi_device_interface
 
 		return $cores;
 	}
+	public static function gpu_xrandr_resolution()
+	{
+		$resolution = false;
+
+		if(pts_client::executable_in_path('xrandr') && getenv('DISPLAY'))
+		{
+			// Read resolution from xrandr
+			$info = shell_exec('xrandr 2>&1 | grep "*"');
+
+			if(strpos($info, '*') !== false)
+			{
+				$res = pts_strings::trim_explode('x', $info);
+				$res[0] = substr($res[0], strrpos($res[0], ' '));
+				$res[1] = substr($res[1], 0, strpos($res[1], ' '));
+				$res = array_map('trim', $res);
+
+				if(is_numeric($res[0]) && is_numeric($res[1]))
+				{
+					$resolution = array($res[0], $res[1]);
+				}
+			}
+		}
+
+		return $resolution;
+	}
 	public static function gpu_screen_resolution()
 	{
 		$resolution = false;
@@ -326,21 +351,7 @@ class phodevi_gpu extends phodevi_device_interface
 
 			if($resolution == false && pts_client::executable_in_path('xrandr'))
 			{
-				// Read resolution from xrandr
-				$info = shell_exec('xrandr 2>&1 | grep "*"');
-
-				if(strpos($info, '*') !== false)
-				{
-					$res = pts_strings::trim_explode('x', $info);
-					$res[0] = substr($res[0], strrpos($res[0], ' '));
-					$res[1] = substr($res[1], 0, strpos($res[1], ' '));
-					$res = array_map('trim', $res);
-
-					if(is_numeric($res[0]) && is_numeric($res[1]))
-					{
-						$resolution = array($res[0], $res[1]);
-					}
-				}
+				$resolution = self::gpu_xrandr_resolution();
 			}
 
 			if($resolution == false && phodevi::is_nvidia_graphics())
@@ -369,6 +380,17 @@ class phodevi_gpu extends phodevi_device_interface
 					}
 				}
 			}
+
+			if($resolution == false && is_readable('/sys/class/graphics/fb0/virtual_size'))
+			{
+				// As last fall-back try reading size of fb
+				$virtual_size = explode(',', pts_file_io::file_get_contents('/sys/class/graphics/fb0/virtual_size'));
+
+				if(count($virtual_size) == 2 && is_numeric($virtual_size[0]) && is_numeric($virtual_size[1]))
+				{
+					$resolution = $virtual_size;
+				}
+			}
 		}
 
 		return $resolution == false ? array(-1, -1) : $resolution;
@@ -950,8 +972,12 @@ class phodevi_gpu extends phodevi_device_interface
 			$info = phodevi_windows_parser::read_cpuz('Display Adapters', 'Name');
 		}
 	
-		if(empty($info) || strpos($info, 'Mesa ') !== false || strpos($info, 'Gallium ') !== false || $info == 'Software Rasterizer')
+		if(empty($info) || strpos($info, 'Mesa ') !== false || strpos($info, 'Gallium ') !== false)
 		{
+			if(phodevi::is_macosx())
+			{
+				$info = phodevi_osx_parser::read_osx_system_profiler('SPDisplaysDataType', 'ChipsetModel');
+			}
 			if(phodevi::is_windows() == false)
 			{
 				$info_pci = phodevi_linux_parser::read_pci('VGA compatible controller', false);
@@ -960,26 +986,59 @@ class phodevi_gpu extends phodevi_device_interface
 				{
 					$info = $info_pci;
 
-					if(strpos($info, 'Intel 2nd Generation Core Family') !== false && is_readable('/sys/kernel/debug/dri/0/i915_capabilities'))
+					if(strpos($info, 'Intel 2nd Generation Core Family') !== false)
 					{
 						// Try to come up with a better non-generic string
-						$i915_caps = file_get_contents('/sys/kernel/debug/dri/0/i915_capabilities');
-						if(($x = strpos($i915_caps, 'gen: ')) !== false)
+						$was_reset = false;
+						if(is_readable('/var/log/Xorg.0.log'))
 						{
-							$gen = substr($i915_caps, ($x + 5));
-							$gen = substr($gen, 0, strpos($gen, PHP_EOL));
+							/*
+							$ cat /var/log/Xorg.0.log | grep -i Chipset
+							[     8.421] (II) intel: Driver for Intel Integrated Graphics Chipsets: i810,
+							[     8.421] (II) VESA: driver for VESA chipsets: vesa
+							[     8.423] (II) intel(0): Integrated Graphics Chipset: Intel(R) Sandybridge Mobile (GT2+)
+							[     8.423] (--) intel(0): Chipset: "Sandybridge Mobile (GT2+)"
+							*/
 
-							if(is_numeric($gen))
+							$xorg_log = file_get_contents('/var/log/Xorg.0.log');
+
+							if(($x = strpos($xorg_log, 'intel(0): Chipset: ')) !== false)
 							{
-								$info = 'Intel Gen' . $gen;
+								$xorg_log = substr($xorg_log, ($x + 19));
+								$xorg_log = str_replace(array('(R)', '"'), null, substr($xorg_log, 0, strpos($xorg_log, PHP_EOL)));
 
-								if(strpos($i915_caps, 'is_mobile: yes') !== false)
+								if(stripos($xorg_log, 'Intel') === false)
 								{
-									$info .= ' Mobile';
+									$xorg_log = 'Intel ' . $xorg_log;
+								}
+
+								// if string is too long, likely not product
+								if(!isset($xorg_log[45]))
+								{
+									$info = $xorg_log;
+									$was_reset = true;
 								}
 							}
 						}
+						if($was_reset == false && is_readable('/sys/kernel/debug/dri/0/i915_capabilities'))
+						{
+							$i915_caps = file_get_contents('/sys/kernel/debug/dri/0/i915_capabilities');
+							if(($x = strpos($i915_caps, 'gen: ')) !== false)
+							{
+								$gen = substr($i915_caps, ($x + 5));
+								$gen = substr($gen, 0, strpos($gen, PHP_EOL));
 
+								if(is_numeric($gen))
+								{
+									$info = 'Intel Gen' . $gen;
+
+									if(strpos($i915_caps, 'is_mobile: yes') !== false)
+									{
+										$info .= ' Mobile';
+									}
+								}
+							}
+						}
 					}
 				}
 			}
@@ -1001,6 +1060,29 @@ class phodevi_gpu extends phodevi_device_interface
 				}
 			}
 
+			if(empty($info) && is_readable('/sys/class/graphics/fb0/name'))
+			{
+				switch(pts_file_io::file_get_contents('/sys/class/graphics/fb0/name'))
+				{
+					case 'omapdrm':
+						$info = 'Texas Instruments OMAP'; // The OMAP DRM driver currently is for OMAP2/3/4 hardware
+						break;
+					case 'exynos':
+						$info = 'Samsung EXYNOS'; // The Exynos DRM driver
+						break;
+					case 'tegra_fb':
+						$info = 'NVIDIA TEGRA'; // The Exynos DRM driver
+						break;
+					default:
+						if(is_file('/dev/mali'))
+						{
+							$info = 'ARM Mali'; // One of the ARM Mali models
+						}
+						break;
+				}
+
+			}
+
 			if(substr($info, -1) == ')' && ($open_p = strrpos($info, '(')) != false)
 			{
 				$end_check = strpos($info, ' ', $open_p);
