@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 	phodevi_motherboard.php: The PTS Device Interface object for the motherboard
 
 	This program is free software; you can redistribute it and/or modify
@@ -84,8 +84,7 @@ class phodevi_motherboard extends phodevi_device_interface
 	}
 	public static function is_genuine($mobo)
 	{
-		// the string length check is a short way of making sure none of those strings are found in the motherboard string
-		return strpos($mobo, ' ') > 1 && strlen($mobo) == strlen(str_ireplace(array('Virtual', 'Bochs', '440BX', 'Megatrends', 'Award ', 'Software', 'Xen', 'HVM ', 'Notebook', 'OEM', ' KVM', 'unknown'), null, $mobo)) && !is_numeric(substr($mobo, 0, strpos($mobo, ' ')));
+		return strpos($mobo, ' ') > 1 && !pts_strings::has_in_istring($mobo, array('Virtual', 'Bochs', '440BX', 'Megatrends', 'Award ', 'Software', 'Xen', 'HVM ', 'Notebook', 'OEM ', ' KVM', 'unknown')) && !is_numeric(substr($mobo, 0, strpos($mobo, ' ')));
 		// pts_strings::string_contains($mobo, pts_strings::CHAR_NUMERIC);
 	}
 	public static function pci_devices()
@@ -387,7 +386,7 @@ class phodevi_motherboard extends phodevi_device_interface
 				$info = strpos($name . ' ', $vendor . ' ') === false ? $vendor . ' ' : null;
 				$info .= $name;
 
-				if($version != false && strpos($info, $version) === false && strlen(pts_strings::remove_from_string($version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL)) == 0)
+				if($version != false && strpos($info, $version) === false && pts_strings::string_only_contains($version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
 				{
 					$info .= (substr($version, 0, 1) == 'v' ? ' ' : ' v') . $version;
 				}
