@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 	phodevi_system.php: The PTS Device Interface object for the system software
 
 	This program is free software; you can redistribute it and/or modify
@@ -252,6 +252,14 @@ class phodevi_system extends phodevi_device_interface
 						{
 							$fs = 'ext2';
 						}
+						else if(is_dir('/proc/fs/ext4/'))
+						{
+							$fs = 'ext4';
+						}
+						else if(is_dir('/proc/fs/ext3/'))
+						{
+							$fs = 'ext3';
+						}
 					}
 					break;
 				case 'Case-sensitive Journaled HFS+':
@@ -341,6 +349,7 @@ class phodevi_system extends phodevi_device_interface
 	{
 		// Reports if system is running virtualized
 		$virtualized = null;
+		$mobo = phodevi::read_name('motherboard');
 		$gpu = phodevi::read_name('gpu');
 		$cpu = phodevi::read_property('cpu', 'model');
 
@@ -352,17 +361,17 @@ class phodevi_system extends phodevi_device_interface
 			{
 				$qemu_version = substr($cpu, (strrpos($cpu, ' ') + 1));
 
-				if(pts_strings::string_only_contains($qemu_version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
+				if(pts_strings::is_version($qemu_version))
 				{
 					$virtualized .= ' ' . $qemu_version;
 				}
 			}
 		}
-		else if(strpos($gpu, 'VMware') !== false || (is_readable('/sys/class/dmi/id/product_name') && stripos(pts_file_io::file_get_contents('/sys/class/dmi/id/product_name'), 'VMware') !== false))
+		else if(stripos($gpu, 'VMware') !== false || (is_readable('/sys/class/dmi/id/product_name') && stripos(pts_file_io::file_get_contents('/sys/class/dmi/id/product_name'), 'VMware') !== false))
 		{
 			$virtualized = 'VMware';
 		}
-		else if(strpos($gpu, 'VirtualBox') !== false || strpos(phodevi::read_name('motherboard'), 'VirtualBox') !== false)
+		else if(stripos($gpu, 'VirtualBox') !== false || stripos(phodevi::read_name('motherboard'), 'VirtualBox') !== false)
 		{
 			$virtualized = 'VirtualBox';
 
@@ -375,6 +384,15 @@ class phodevi_system extends phodevi_device_interface
 					$virtualized .= ' ' . $vbox_manage;
 				}
 			}
+			else if($modinfo = pts_client::executable_in_path('modinfo'))
+			{
+				$modinfo = trim(shell_exec('modinfo -F version vboxguest 2> /dev/null'));
+
+				if($modinfo != null && pts_strings::is_version($modinfo))
+				{
+					$virtualized .= ' ' . $modinfo;
+				}
+			}
 
 		}
 		else if(is_file('/sys/class/dmi/id/sys_vendor') && pts_file_io::file_get_contents('/sys/class/dmi/id/sys_vendor') == 'Xen')
@@ -391,6 +409,14 @@ class phodevi_system extends phodevi_device_interface
 
 			// $virtualized should be then e.g. 'Xen HVM domU 4.1.1'
 		}
+		else if(stripos($gpu, 'Microsoft Hyper-V') !== false)
+		{
+			$virtualized = 'Microsoft Hyper-V Server';
+		}
+		else if(stripos($mobo, 'Parallels Software') !== false)
+		{
+			$virtualized = 'Parallels Virtualization';
+		}
 
 		return $virtualized;
 	}
@@ -405,7 +431,26 @@ class phodevi_system extends phodevi_device_interface
 			{
 				// GCC
 				// If it's a link, ensure that it's not linking to llvm/clang or something
-				$compilers['gcc'] = 'GCC ' . trim(shell_exec('gcc -dumpversion 2>&1'));
+				$version = trim(shell_exec('gcc -dumpversion 2>&1'));
+				if(pts_strings::is_version($version))
+				{
+					$v = shell_exec('gcc -v 2>&1');
+
+					if(($t = strrpos($v, $version . ' ')) !== false)
+					{
+						$v = substr($v, ($t + strlen($version) + 1));
+						$v = substr($v, 0, strpos($v, ' '));
+
+						if($v != null && ctype_digit($v))
+						{
+							// On development versions the release date is expressed
+							// e.g. gcc version 4.7.0 20120314 (prerelease) (GCC)
+							$version .= ' ' . $v;
+						}
+					}
+
+					$compilers['gcc'] = 'GCC ' . $version;
+				}
 			}
 		}
 
@@ -443,6 +488,12 @@ class phodevi_system extends phodevi_device_interface
 			}
 		}
 
+		if(pts_client::executable_in_path('pgcpp') || pts_client::executable_in_path('pgCC'))
+		{
+			// The Portland Group Compilers
+			$compilers['pgcpp'] = 'PGI C-C++ Workstation';
+		}
+
 		if(pts_client::executable_in_path('clang'))
 		{
 			// Clang
@@ -455,7 +506,7 @@ class phodevi_system extends phodevi_device_interface
 				$compiler_info = substr($compiler_info, ($cv_pos + 14));
 				$clang_version = substr($compiler_info, 0, strpos($compiler_info, ' '));
 
-				if(pts_strings::string_only_contains($clang_version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
+				if(pts_strings::is_version($clang_version))
 				{
 					// Also see if there is a Clang SVN tag to fetch
 					$compiler_info = substr($compiler_info, 0, strpos($compiler_info, PHP_EOL));
@@ -501,7 +552,7 @@ class phodevi_system extends phodevi_device_interface
 				$info = substr($info, 0, strpos($info, PHP_EOL, $s));
 				$info = substr($info, (strrpos($info, ' ') + 1));
 
-				if(pts_strings::string_only_contains($info, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
+				if(pts_strings::is_version($info))
 				{
 					$compilers['llvmc'] = 'LLVM ' . $info;
 				}
@@ -541,10 +592,37 @@ class phodevi_system extends phodevi_device_interface
 			$compilers['icc'] = 'ICC';
 		}
 
-		// Try to make the compiler that's used by default to appear first
-		if(pts_client::read_env('CC') && isset($compilers[basename(pts_client::read_env('CC'))]))
+		if(phodevi::is_macosx() && pts_client::executable_in_path('xcodebuild'))
 		{
-			$cc_env = basename(pts_client::read_env('CC'));
+			$xcode = phodevi_osx_parser::read_osx_system_profiler('SPDeveloperToolsDataType', 'Xcode');
+			$xcode = substr($xcode, 0, strpos($xcode, ' '));
+
+			if($xcode)
+			{
+				$compilers['Xcode'] = 'Xcode ' . $xcode;
+			}
+		}
+
+		if(pts_client::executable_in_path('nvcc'))
+		{
+			// NVIDIA CUDA Compiler Driver
+			$nvcc = shell_exec('nvcc --version 2>&1');
+			if(($s = strpos($nvcc, 'release ')) !== false)
+			{
+				$nvcc = str_replace(array(','), null, substr($nvcc, ($s + 8)));
+				$nvcc = substr($nvcc, 0, strpos($nvcc, ' '));
+
+				if(pts_strings::is_version($nvcc))
+				{
+					$compilers['CUDA'] = 'CUDA ' . $nvcc;
+				}
+			}
+		}
+
+		// Try to make the compiler that's used by default to appear first
+		if(pts_client::read_env('CC') && isset($compilers[basename(pts_strings::first_in_string(pts_client::read_env('CC'), ' '))]))
+		{
+			$cc_env = basename(pts_strings::first_in_string(pts_client::read_env('CC'), ' '));
 			$default_compiler = $compilers[$cc_env];
 			unset($compilers[$cc_env]);
 			array_unshift($compilers, $default_compiler);
@@ -626,6 +704,12 @@ class phodevi_system extends phodevi_device_interface
 	}
 	public static function sw_operating_system()
 	{
+		if(!PTS_IS_CLIENT)
+		{
+			// TODO: Figure out why this function is sometimes called from OpenBenchmarking.org....
+			return false;
+		}
+
 		// Determine the operating system release
 		if(phodevi::is_linux())
 		{
@@ -708,6 +792,15 @@ class phodevi_system extends phodevi_device_interface
 					$os = php_uname('s');
 				}
 			}
+			else if(strpos($os, ' ') === false)
+			{
+				// The OS string is only one word, likely a problem...
+				if(is_file('/etc/arch-release') && stripos($os, 'Arch') === false)
+				{
+					// On at least some Arch installs (ARM) the file is empty so would have missed above check
+					$os = trim('Arch Linux ' . $os);
+				}
+			}
 		}
 		else
 		{
@@ -820,11 +913,7 @@ class phodevi_system extends phodevi_device_interface
 			$version = substr($lx_output, strpos(' ', $lx_output) + 1);
 
 			$desktop_environment = 'LXDE';
-
-			if(strlen(pts_strings::keep_in_string($version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL)) == strlen($version))
-			{
-				$desktop_version = $version;
-			}
+			$desktop_version = $version;
 		}
 		else if(pts_client::is_process_running('xfce4-session') || pts_client::is_process_running('xfce-mcs-manager'))
 		{
@@ -849,7 +938,7 @@ class phodevi_system extends phodevi_device_interface
 		{
 			$desktop = $desktop_environment;
 
-			if(!empty($desktop_version) && pts_strings::string_only_contains($desktop_version, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DECIMAL))
+			if(!empty($desktop_version) && pts_strings::is_version($desktop_version))
 			{
 				$desktop .= ' ' . $desktop_version;
 			}
@@ -954,6 +1043,15 @@ class phodevi_system extends phodevi_device_interface
 							$display_driver = 'radeon';
 						}
 						break;
+					case 'vmwgfx':
+						// See if it's VMware driver
+						$driver_version = phodevi_parser::read_xorg_module_version('vmware_drv');
+
+						if($driver_version != false)
+						{
+							$display_driver = 'vmware';
+						}
+						break;
 					case 'radeon':
 						// RadeonHD driver also reports DRI driver as 'radeon', so try reading that instead
 						$driver_version = phodevi_parser::read_xorg_module_version('radeonhd_drv');
@@ -980,11 +1078,23 @@ class phodevi_system extends phodevi_device_interface
 							}
 						}
 						break;
+					default:
+						if(is_readable('/sys/class/graphics/fb0/name'))
+						{
+							// This path works for at least finding NVIDIA Tegra 2 DDX (via tegra_fb)
+							$display_driver = file_get_contents('/sys/class/graphics/fb0/name');
+							$display_driver = str_replace(array('drm', '_fb'), null, $display_driver);
+							$driver_version = phodevi_parser::read_xorg_module_version($display_driver . '_drv');
+						}
+						break;
 				}
 			}
 
 			if($driver_version == false)
 			{
+				// If the version is empty, chances are the DDX driver string is incorrect
+				$display_driver = null;
+
 				// See if the VESA or fbdev driver is in use
 				foreach(array('vesa', 'fbdev') as $drv)
 				{
@@ -1032,18 +1142,18 @@ class phodevi_system extends phodevi_device_interface
 			$info = phodevi_parser::read_nvidia_extension('OpenGLVersion');
 		}
 
-		if($info == null && pts_client::executable_in_path('glxinfo'))
+		if($info == null)
 		{
 			$info = phodevi_parser::software_glxinfo_version();
 
-			if(($pos = strpos($info, ' ')) != false && strpos($info, 'Mesa') === false)
+			if($info && ($pos = strpos($info, ' ')) != false && strpos($info, 'Mesa') === false)
 			{
 				$info = substr($info, 0, $pos);
 			}
 
 			$renderer = phodevi_parser::read_glx_renderer();
 
-			if(($s = strpos($renderer, 'Gallium')) !== false)
+			if($renderer && ($s = strpos($renderer, 'Gallium')) !== false)
 			{
 				$renderer = substr($renderer, $s);
 				$renderer = substr($renderer, 0, strpos($renderer, ' ', strpos($renderer, '.')));
@@ -1087,6 +1197,63 @@ class phodevi_system extends phodevi_device_interface
 
 		return $info;
 	}
+	public static function sw_compiler_build_configuration($compiler)
+	{
+		$cc = shell_exec($compiler . ' -v 2>&1');
+
+		if(($t = stripos($cc, 'Configured with: ')) !== false)
+		{
+			$cc = substr($cc, ($t + 18));
+			$cc = substr($cc, 0, strpos($cc, PHP_EOL));
+			$cc = explode(' ', $cc);
+			array_shift($cc); // this should just be the configure call (i.e. ../src/configure)
+
+			$drop_arguments = array(
+				'--with-pkgversion=',
+				'--with-bugurl=',
+				'--prefix=',
+				'--program-suffix=',
+				'--libexecdir=',
+				'--infodir=',
+				'--libdir=',
+				'--with-sysroot=',
+				'--with-gxx-include-dir=',
+				'--with-system-zlib',
+				'--enable-linker-build-id',
+				'--without-included-gettext'
+				);
+
+			foreach($cc as $i => $argument)
+			{
+				$arg_length = strlen($argument);
+				if($argument[0] != '-')
+				{
+					unset($cc[$i]);
+				}
+				else
+				{
+					foreach($drop_arguments as $check_to_drop)
+					{
+						$len = strlen($check_to_drop);
+
+						if($len <= $arg_length && substr($argument, 0, $len) == $check_to_drop)
+						{
+							unset($cc[$i]);
+						}
+					}
+				}
+			}
+
+			sort($cc);
+			$cc = implode(' ', $cc);
+		}
+		else
+		{
+			$cc = null;
+		}
+
+		return $cc;
+	}
 	public static function sw_dri_display_driver()
 	{
 		$dri_driver = false;
