@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 	phodevi_parser.php: General parsing functions used by different parts of Phodevi that are supported by more than one OS
 
 	This program is free software; you can redistribute it and/or modify
@@ -74,16 +74,32 @@ class phodevi_parser
 	}
 	public static function read_glx_renderer()
 	{
-		$info = pts_client::executable_in_path('glxinfo') != false ? shell_exec('glxinfo 2>&1 | grep renderer') : null;
-
-		if(($pos = strpos($info, 'renderer string:')) > 0)
+		if(pts_client::executable_in_path('glxinfo'))
 		{
-			$info = substr($info, $pos + 16);
+			$info = shell_exec('glxinfo 2>&1');
+		}
+		else if(pts_client::executable_in_path('fglrxinfo'))
+		{
+			$info = shell_exec('fglrxinfo 2>&1');
+		}
+		else
+		{
+			return false;
+		}
+
+		if(($pos = strpos($info, 'OpenGL renderer string:')) !== false)
+		{
+			$info = substr($info, $pos + 24);
 			$info = trim(substr($info, 0, strpos($info, "\n")));
 		}
 		else
 		{
-			$info = null;
+			$info = false;
+		}
+
+		if(stripos($info, 'Software Rasterizer') !== false)
+		{
+			$info = false;
 		}
 
 		return $info;
@@ -193,10 +209,17 @@ class phodevi_parser
 
 		if($info == -1)
 		{
-			$info = null;
-			$glxinfo = shell_exec('glxinfo 2> /dev/null');
+			$info = false;
+			if(pts_client::executable_in_path('glxinfo'))
+			{
+				$glxinfo = shell_exec('glxinfo 2> /dev/null');
+			}
+			else if(pts_client::executable_in_path('fglrxinfo'))
+			{
+				$glxinfo = shell_exec('fglrxinfo 2> /dev/null');
+			}
 
-			if(($pos = strpos($glxinfo, 'OpenGL version string:')) !== false)
+			if(isset($glxinfo) && ($pos = strpos($glxinfo, 'OpenGL version string:')) !== false)
 			{
 				$info = substr($glxinfo, $pos + 23);
 				$info = substr($info, 0, strpos($info, "\n"));
