@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2011, Phoronix Media
-	Copyright (C) 2010 - 2011, Michael Larabel
+	Copyright (C) 2010 - 2012, Phoronix Media
+	Copyright (C) 2010 - 2012, Michael Larabel
 	pts_OverviewGraph.php: A graping object to create an "overview" / mini graphs of a pts_result_file for pts_Graph
 
 	This program is free software; you can redistribute it and/or modify
@@ -65,24 +65,24 @@ class pts_OverviewGraph extends pts_Graph
 			return;
 		}
 
-		$this->graph_font_size_identifiers = 6.5;
-		$this->graph_attr_width = 1000;
+		$this->i['identifier_size'] = 6.5;
+		$this->i['graph_width'] = 1000;
 
-		list($longest_title_width, $longest_title_height) = bilde_renderer::soft_text_string_dimensions(pts_strings::find_longest_string($this->test_titles), $this->graph_font, $this->graph_font_size_identifiers);
+		list($longest_title_width, $longest_title_height) = pts_svg_dom::estimate_text_dimensions(pts_strings::find_longest_string($this->test_titles), $this->i['identifier_size']);
 
-		$this->graph_left_start += 20;
-		$this->graphs_per_row = floor(($this->graph_attr_width - $this->graph_left_start - $this->graph_left_end_opp) / ($longest_title_width + 2));
-		$this->graph_item_width = floor(($this->graph_attr_width - $this->graph_left_start - $this->graph_left_end_opp) / $this->graphs_per_row);
+		$this->i['left_start'] += 20;
+		$this->graphs_per_row = floor(($this->i['graph_width'] - $this->i['left_start'] - $this->i['left_end_right']) / ($longest_title_width + 2));
+		$this->graph_item_width = floor(($this->i['graph_width'] - $this->i['left_start'] - $this->i['left_end_right']) / $this->graphs_per_row);
 		$this->graph_row_count = ceil(count($this->test_titles) / $this->graphs_per_row);
 
-		$height = $this->graph_top_start + ($this->graph_row_count * ($this->graph_row_height + 15));
+		$height = $this->i['top_start'] + ($this->graph_row_count * ($this->graph_row_height + 15));
 
 		$this->graph_title = $result_file->get_title();
 		$this->graph_y_title = null;
-		$this->graph_proportion = 'HIB';
-		$this->graph_background_lines = true;
+		$this->i['graph_proportion'] = 'HIB';
+		$this->i['show_background_lines'] = true;
 
-		$this->update_graph_dimensions($this->graph_attr_width, $height, true);
+		$this->update_graph_dimensions($this->i['graph_width'], $height, true);
 		$this->result_file = $result_file;
 
 		return true;
@@ -93,15 +93,15 @@ class pts_OverviewGraph extends pts_Graph
 	}
 	public function renderGraph()
 	{
-		$this->requestRenderer('SVG');
 		$this->graph_data_title = &$this->system_identifiers;
-		$this->graph_attr_marks = 6;
-		$this->graph_maximum_value = 1.2;
+		$this->i['mark_count'] = 6;
+		$this->i['graph_max_value'] = 1.2;
 		$l_height = 15;
+		$this->i['key_line_height'] = $l_height;
 
 		if(($key_count = count($this->graph_data_title)) > 8)
 		{
-			$this->update_graph_dimensions(-1, $this->graph_attr_height + (floor(($key_count - 8) / 4) * 14), true);
+			$this->update_graph_dimensions(-1, $this->i['graph_height'] + (floor(($key_count - 8) / 4) * 14), true);
 		}
 
 		// Do the actual work
@@ -110,8 +110,8 @@ class pts_OverviewGraph extends pts_Graph
 
 		for($i = 0; $i < $this->graph_row_count; $i++)
 		{
-			$this->render_graph_base($this->graph_left_start, $this->graph_top_start + ($i * ($this->graph_row_height + $l_height)), $this->graph_left_end, $this->graph_top_start + ($i * ($this->graph_row_height + $l_height)) + $this->graph_row_height);
-			$this->render_graph_value_ticks($this->graph_left_start, $this->graph_top_start + ($i * ($this->graph_row_height + $l_height)), $this->graph_left_end, $this->graph_top_start + ($i * ($this->graph_row_height + $l_height)) + $this->graph_row_height);
+			$this->render_graph_base($this->i['left_start'], $this->i['top_start'] + ($i * ($this->graph_row_height + $l_height)), $this->i['graph_left_end'], $this->i['top_start'] + ($i * ($this->graph_row_height + $l_height)) + $this->graph_row_height);
+			$this->render_graph_value_ticks($this->i['left_start'], $this->i['top_start'] + ($i * ($this->graph_row_height + $l_height)), $this->i['graph_left_end'], $this->i['top_start'] + ($i * ($this->graph_row_height + $l_height)) + $this->graph_row_height);
 		}
 
 		$row = 0;
@@ -124,12 +124,12 @@ class pts_OverviewGraph extends pts_Graph
 
 		foreach($this->result_file->get_result_objects() as $i => $result_object)
 		{
-			$top_start = $this->graph_top_start + ($row * ($this->graph_row_height + $l_height));
-			$top_end = $this->graph_top_start + ($row * ($this->graph_row_height + $l_height)) + $this->graph_row_height;
-			$px_bound_left = $this->graph_left_start + ($this->graph_item_width * ($col % $this->graphs_per_row));
+			$top_start = $this->i['top_start'] + ($row * ($this->graph_row_height + $l_height));
+			$top_end = round($this->i['top_start'] + ($row * ($this->graph_row_height + $l_height)) + $this->graph_row_height);
+			$px_bound_left = $this->i['left_start'] + ($this->graph_item_width * ($col % $this->graphs_per_row));
 			$px_bound_right = $px_bound_left + $this->graph_item_width;
 
-			$this->graph_image->write_text_center($result_object->test_profile->get_title(), $this->graph_font, $this->graph_font_size_identifiers, $this->graph_color_headers, $px_bound_left, $top_end + 3, $px_bound_right, $top_end + 3, false);
+			$this->svg_dom->add_text_element($result_object->test_profile->get_title(), array('x' => ($px_bound_left + ($this->graph_item_width * 0.5)), 'y' => ($top_end + 3), 'font-size' => $this->i['identifier_size'], 'fill' => self::$c['color']['headers'], 'text-anchor' => 'middle', 'dominant-baseline' => 'text-before-edge'));
 
 			if($result_object->test_profile->get_display_format() == 'BAR_GRAPH')
 			{
@@ -159,13 +159,13 @@ class pts_OverviewGraph extends pts_Graph
 							break;
 					}
 
-					$graph_size = round(($value / $this->graph_maximum_value) * ($top_end - $top_start));
+					$graph_size = round(($value / $this->i['graph_max_value']) * ($top_end - $top_start));
 					$value_plot_top = $top_end + 1 - $graph_size;
 
 					$px_left = $px_bound_left + $inter_width + ($bar_width * $x);
 					$px_right = $px_left + $bar_width;
 
-					$this->graph_image->draw_rectangle_with_border($px_left, $value_plot_top, $px_right, $top_end, $paint_color, $this->graph_color_body_light, null);
+					$this->svg_dom->add_element('rect', array('x' => $px_left, 'y' => $value_plot_top, 'width' => $bar_width, 'height' => ($top_end - $value_plot_top), 'fill' => $paint_color, 'stroke' => self::$c['color']['body_light'], 'stroke-width' => 1));
 				}
 
 				$has_graphed_a_bar = true;
@@ -173,8 +173,8 @@ class pts_OverviewGraph extends pts_Graph
 
 			if(($i + 1) % $this->graphs_per_row == 0 && $i != 0)
 			{
-				$this->graph_image->draw_dashed_line($this->graph_left_start + $this->graph_item_width, $top_end, $this->graph_left_end - ($this->graph_attr_width % $this->graph_item_width), $top_end, $this->graph_color_notches, 10, 1, $this->graph_item_width - 1);
-				$this->graph_image->draw_line($this->graph_left_start, $top_end, $this->graph_left_end, $top_end, $this->graph_color_notches, 1);
+				$this->svg_dom->draw_svg_line($this->i['left_start'] + $this->graph_item_width, $top_end, $this->i['graph_left_end'] - ($this->i['graph_width'] % $this->graph_item_width), $top_end, self::$c['color']['notches'], 10, array('stroke-dasharray' => '1,' . ($this->graph_item_width - 1)));
+				$this->svg_dom->draw_svg_line($this->i['left_start'], $top_end, $this->i['graph_left_end'], $top_end, self::$c['color']['notches'], 1);
 
 				$row++;
 			}
@@ -188,11 +188,9 @@ class pts_OverviewGraph extends pts_Graph
 		}
 
 
-		//$this->render_graph_base($this->graph_left_start, $this->graph_top_start, $this->graph_left_end, $this->graph_top_end);
+		//$this->render_graph_base($this->i['left_start'], $this->i['top_start'], $this->i['graph_left_end'], $this->i['graph_top_end']);
 		$this->render_graph_heading();
 		//$this->render_graph_watermark();
-
-		return $this->return_graph_image();
 	}
 }
 
