@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2010, Phoronix Media
-	Copyright (C) 2008 - 2010, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,9 +22,16 @@
 
 class pts_network
 {
+	private static $disable_network_support = false;
+	private static $network_proxy = false;
+
+	public static function network_support_available()
+	{
+		return self::$disable_network_support == false;
+	}
 	public static function http_get_contents($url, $override_proxy = false, $override_proxy_port = false)
 	{
-		if(defined('NO_NETWORK_COMMUNICATION'))
+		if(!pts_network::network_support_available())
 		{
 			return false;
 		}
@@ -36,7 +43,7 @@ class pts_network
 	}
 	public static function http_upload_via_post($url, $to_post_data)
 	{
-		if(defined('NO_NETWORK_COMMUNICATION'))
+		if(!pts_network::network_support_available())
 		{
 			return false;
 		}
@@ -45,13 +52,13 @@ class pts_network
 		$http_parameters = array('http' => array('method' => 'POST', 'content' => $upload_data));
 		$stream_context = pts_network::stream_context_create($http_parameters);
 		$opened_url = fopen($url, 'rb', false, $stream_context);
-		$response = stream_get_contents($opened_url);
+		$response = $opened_url ? stream_get_contents($opened_url) : false;
 
 		return $response;
 	}
 	public static function download_file($download, $to)
 	{
-		if(defined('NO_NETWORK_COMMUNICATION'))
+		if(!pts_network::network_support_available())
 		{
 			return false;
 		}
@@ -119,9 +126,9 @@ class pts_network
 			curl_setopt($cr, CURLOPT_PROGRESSFUNCTION, array('pts_network', 'curl_status_callback'));
 		}
 
-		if(defined('NETWORK_PROXY'))
+		if(self::$network_proxy)
 		{
-			curl_setopt($cr, CURLOPT_PROXY, NETWORK_PROXY);
+			curl_setopt($cr, CURLOPT_PROXY, self::$network_proxy['proxy']);
 		}
 
 		curl_exec($cr);
@@ -162,10 +169,10 @@ class pts_network
 			$parameters = array();
 		}
 
-		if($proxy_address == false && $proxy_port == false && defined('NETWORK_PROXY'))
+		if($proxy_address == false && $proxy_port == false && self::$network_proxy)
 		{
-			$proxy_address = NETWORK_PROXY_ADDRESS;
-			$proxy_port = NETWORK_PROXY_PORT;
+			$proxy_address = self::$network_proxy['address'];
+			$proxy_port = self::$network_proxy['port'];
 		}
 
 		if($proxy_address != false && $proxy_port != false && is_numeric($proxy_port))
@@ -227,15 +234,15 @@ class pts_network
 	{
 		if(($proxy_address = pts_config::read_user_config('PhoronixTestSuite/Options/Networking/ProxyAddress', false)) && ($proxy_port = pts_config::read_user_config('PhoronixTestSuite/Options/Networking/ProxyPort', false)))
 		{
-			define('NETWORK_PROXY', $proxy_address . ':' . $proxy_port);
-			define('NETWORK_PROXY_ADDRESS', $proxy_address);
-			define('NETWORK_PROXY_PORT', $proxy_port);
+			self::$network_proxy['proxy'] = $proxy_address . ':' . $proxy_port;
+			self::$network_proxy['address'] = $proxy_address;
+			self::$network_proxy['port'] = $proxy_port;
 		}
 		else if(($env_proxy = getenv('http_proxy')) != false && count($env_proxy = pts_strings::colon_explode($env_proxy)) == 2)
 		{
-			define('NETWORK_PROXY', $env_proxy[0] . ':' . $env_proxy[1]);
-			define('NETWORK_PROXY_ADDRESS', $env_proxy[0]);
-			define('NETWORK_PROXY_PORT', $env_proxy[1]);
+			self::$network_proxy['proxy'] = $env_proxy[0] . ':' . $env_proxy[1];
+			self::$network_proxy['address'] = $env_proxy[0];
+			self::$network_proxy['port'] = $env_proxy[1];
 		}
 
 		define('NETWORK_TIMEOUT', pts_config::read_user_config('PhoronixTestSuite/Options/Networking/Timeout', 20));
@@ -243,17 +250,17 @@ class pts_network
 		if(ini_get('allow_url_fopen') == 'Off')
 		{
 			echo PHP_EOL . 'The allow_url_fopen option in your PHP configuration must be enabled for network support.' . PHP_EOL . PHP_EOL;
-			define('NO_NETWORK_COMMUNICATION', true);
+			self::$disable_network_support = true;
 		}
 		else if(pts_config::read_bool_config('PhoronixTestSuite/Options/Networking/NoNetworkCommunication', 'FALSE'))
 		{
-			define('NO_NETWORK_COMMUNICATION', true);
 			echo PHP_EOL . 'Network Communication Is Disabled For Your User Configuration.' . PHP_EOL . PHP_EOL;
+			self::$disable_network_support = true;
 		}
 		else if(pts_flags::no_network_communication() == true)
 		{
-			define('NO_NETWORK_COMMUNICATION', true);
 			//echo PHP_EOL . 'Network Communication Is Disabled For Your User Configuration.' . PHP_EOL . PHP_EOL;
+			self::$disable_network_support = true;
 		}
 		else
 		{
@@ -268,13 +275,13 @@ class pts_network
 				// If google.com fails to resolve, it will simply return the original string
 				if(gethostbyname('google.com') == 'google.com')
 				{
-					define('NO_NETWORK_COMMUNICATION', true);
 					echo PHP_EOL . 'NOTICE: No Network Connectivity' . PHP_EOL . PHP_EOL;
+					self::$disable_network_support = true;
 				}
 			}
 		}
 
-		if(!defined('NO_NETWORK_COMMUNICATION') && ini_get('file_uploads') == 'Off')
+		if(pts_network::network_support_available() == false && ini_get('file_uploads') == 'Off')
 		{
 			echo PHP_EOL . 'The file_uploads option in your PHP configuration must be enabled for network support.' . PHP_EOL . PHP_EOL;
 		}
