@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2011, Phoronix Media
-	Copyright (C) 2010 - 2011, Michael Larabel
+	Copyright (C) 2010 - 2012, Phoronix Media
+	Copyright (C) 2010 - 2012, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -62,8 +62,7 @@ class pts_openbenchmarking
 
 		if(strlen($gsid) == 9)
 		{
-			if(strlen(pts_strings::keep_in_string(substr($gsid, 0, 6), pts_strings::CHAR_LETTER)) == 6 &&
-			strlen(pts_strings::keep_in_string(substr($gsid, 6, 3), pts_strings::CHAR_NUMERIC)) == 3)
+			if(ctype_upper(substr($gsid, 0, 6)) && ctype_digit(substr($gsid, 6, 3)))
 			{
 				$gsid_valid = true;
 			}
@@ -77,8 +76,7 @@ class pts_openbenchmarking
 
 		if(strlen($gside) == 12)
 		{
-			if(strlen(pts_strings::keep_in_string(substr($gside, 0, 10), pts_strings::CHAR_LETTER)) == 10 &&
-			strlen(pts_strings::keep_in_string(substr($gside, 10, 2), pts_strings::CHAR_NUMERIC)) == 2)
+			if(ctype_upper(substr($gside, 0, 10)) && ctype_digit(substr($gside, 10, 2)))
 			{
 				$gside_valid = true;
 			}
@@ -92,8 +90,7 @@ class pts_openbenchmarking
 
 		if(strlen($gsidp) == 10)
 		{
-			if(strlen(pts_strings::keep_in_string(substr($gsidp, 0, 9), pts_strings::CHAR_LETTER)) == 9 &&
-			strlen(pts_strings::keep_in_string(substr($gsidp, 9, 1), pts_strings::CHAR_NUMERIC)) == 1)
+			if(ctype_upper(substr($gsidp, 0, 9)) &&	ctype_digit(substr($gsidp, 9, 1)))
 			{
 				$gsidp_valid = true;
 			}
@@ -146,6 +143,10 @@ class pts_openbenchmarking
 					pts_openbenchmarking::clone_openbenchmarking_result_system_logs($id, pts_client::setup_test_result_directory($id), $json_response['openbenchmarking']['result']['system_logs_available']);
 				}
 			}
+			else
+			{
+				echo PHP_EOL . 'ERROR: Validating the result file schema failed.' . PHP_EOL . PHP_EOL;
+			}
 		}
 		else if(PTS_IS_CLIENT && isset($json_response['openbenchmarking']['result']['error']))
 		{
@@ -189,9 +190,9 @@ class pts_openbenchmarking
 				{
 					$us = strlen($segments[1]);
 
-					if($us > 1 && $us < 9 && pts_strings::string_only_contains($segments[1], pts_strings::CHAR_LETTER | pts_strings::CHAR_NUMERIC))
+					if($us > 1 && $us < 9 && ctype_alnum($segments[1]))
 					{
-						if(pts_strings::string_only_contains($segments[2], pts_strings::CHAR_LETTER | pts_strings::CHAR_NUMERIC))
+						if(ctype_alnum($segments[2]))
 						{
 							$valid = true;
 						}
@@ -208,7 +209,7 @@ class pts_openbenchmarking
 
 		if(strlen($id) == 4)
 		{
-			if(pts_strings::string_only_contains($id, pts_strings::CHAR_LETTER))
+			if(ctype_alpha($id))
 			{
 				$valid = true;
 			}
