@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -22,12 +22,12 @@
 
 class pts_render
 {
-	public static $last_graph_object = null;
-
 	public static function render_graph(&$result_object, &$result_file = null, $save_as = false, $extra_attributes = null)
 	{
 		$graph = self::render_graph_process($result_object, $result_file, $save_as, $extra_attributes);
-		return $graph->renderGraph();
+		$graph->renderGraph();
+
+		return $graph->svg_dom->output($save_as);
 	}
 	public static function render_graph_inline_embed(&$object, &$result_file = null, $extra_attributes = null, $nested = true)
 	{
@@ -41,46 +41,37 @@ class pts_render
 		}
 		else
 		{
-			return null;
+			return false;
 		}
 
-		$graph->render_graph_start();
-		switch($graph->graph_image->get_renderer())
+		$graph->renderGraph();
+		$output_format = 'SVG';
+		$graph = $graph->svg_dom->output(null, $output_format);
+
+		switch($output_format)
 		{
 			case 'PNG':
 			case 'JPG':
-				$save_as = tempnam('/tmp', 'pts_gd_render');
-				$graph->saveGraphToFile($save_as);
-				$graph->render_graph_finish();
-				$graph = file_get_contents($save_as);
-				unlink($save_as);
-
 				if($nested)
 				{
 					$graph = '<img src="data:image/png;base64,' . base64_encode($graph) . '" />';
 				}
 				else
 				{
-					header('Content-Type: image/' . strtolower($graph->graph_image->get_renderer()));
+					header('Content-Type: image/' . strtolower($output_format));
 				}
 				break;
+			default:
 			case 'SVG':
-				$svg_graph = $graph->render_graph_finish();
-
 				if($nested)
 				{
 					// strip out any DOCTYPE and other crud that would be redundant, so start at SVG tag
-					$svg_graph = substr($svg_graph, strpos($svg_graph, '<svg'));
+					$graph = substr($graph, strpos($graph, '<svg'));
 				}
 				else
 				{
 					header('Content-type: image/svg+xml');
 				}
-
-				$graph = $svg_graph;
-				break;
-			default:
-				$graph = $graph->render_graph_finish();
 				break;
 		}
 
@@ -128,7 +119,7 @@ class pts_render
 			if($result_object->test_profile->get_display_format() != 'PIE_CHART')
 			{
 				$result_table = false;
-				pts_render::compact_result_file_test_object($result_object, $result_table, $result_file->is_multi_way_inverted(), $extra_attributes);
+				pts_render::compact_result_file_test_object($result_object, $result_table, $result_file, $extra_attributes);
 			}
 		}
 		else if(in_array($result_object->test_profile->get_display_format(), array('LINE_GRAPH', 'FILLED_LINE_GRAPH')))
@@ -165,6 +156,10 @@ class pts_render
 	}
 	public static function render_graph_process(&$result_object, &$result_file = null, $save_as = false, $extra_attributes = null)
 	{
+		if(isset($extra_attributes['sort_result_buffer']))
+		{
+			$result_object->test_result_buffer->sort_buffer_items();
+		}
 		if(isset($extra_attributes['reverse_result_buffer']))
 		{
 			$result_object->test_result_buffer->buffer_values_reverse();
@@ -201,12 +196,7 @@ class pts_render
 		self::multi_way_compact($result_file, $result_object, $extra_attributes);
 
 		$display_format = $result_object->test_profile->get_display_format();
-		static $bar_orientation = null;
-
-		if($bar_orientation == null)
-		{
-			$bar_orientation = pts_Graph::$graph_config->getXmlValue('PhoronixTestSuite/Graphs/General/BarOrientation');
-		}
+		$bar_orientation = 'HORIZONTAL'; // default to horizontal bar graph
 
 		switch($display_format)
 		{
@@ -378,18 +368,163 @@ class pts_render
 				break;
 		}
 
-		if($save_as)
-		{
-			$graph->saveGraphToFile($save_as);
-		}
-
-		if(PTS_IS_CLIENT)
-		{
-			self::$last_graph_object = $graph;
-		}
+		self::report_test_notes_to_graph($graph, $result_object);
 
 		return $graph;
 	}
+	public static function report_system_notes_to_table(&$result_file, &$table)
+	{
+		$system_json = $result_file->get_system_json();
+		$identifiers = $result_file->get_system_identifiers();
+		$compiler_configuration = array();
+		$disk_options = array();
+
+		foreach($system_json as $i => $json)
+		{
+			if(isset($json['compiler-configuration']) && $json['compiler-configuration'] != null)
+			{
+				$compiler_configuration[$identifiers[$i]] = $json['compiler-configuration'];
+			}
+			if(isset($json['disk-scheduler']) && isset($json['disk-mount-options']))
+			{
+				$disk_options[$identifiers[$i]] = $json['disk-scheduler'] . ' / ' . $json['disk-mount-options'];
+			}
+		}
+
+		switch(count(array_unique($compiler_configuration)))
+		{
+			case 0:
+				break;
+			case 1:
+				$intent = -1;
+				if($result_file->get_system_count() > 1 && ($intent = pts_result_file_analyzer::analyze_result_file_intent($result_file, $intent, true)) && isset($intent[0]) && is_array($intent[0]) && array_shift($intent[0]) == 'Compiler')
+				{
+					// Even if the compiler build configuration isn't changing but a compiler is being compared, might as well report its build configuration
+					$table->addTestNote('CC: ' . array_pop($compiler_configuration));
+				}
+				break;
+			default:
+				foreach($compiler_configuration as $identifier => $configuration)
+				{
+					$table->addTestNote($identifier . ' CC: ' . $configuration);
+				}
+				break;
+		}
+
+		switch(count(array_unique($disk_options)))
+		{
+			case 0:
+				break;
+			case 1:
+				$table->addTestNote(array_pop($disk_options));
+				break;
+			default:
+				foreach($disk_options as $identifier => $configuration)
+				{
+					$table->addTestNote($identifier . ': ' . $configuration);
+				}
+				break;
+		}
+	}
+	protected static function report_test_notes_to_graph(&$graph, &$result_object)
+	{
+		// do some magic here to report any test notes....
+		$json = array();
+		$unique_compiler_data = array();
+		foreach($result_object->test_result_buffer->get_buffer_items() as $buffer_item)
+		{
+			$result_json = $buffer_item->get_result_json();
+
+			if(!empty($result_json))
+			{
+				$json[$buffer_item->get_result_identifier()] = $result_json;
+				if(isset($result_json['compiler-options']) && !empty($result_json['compiler-options']))
+				{
+					pts_arrays::unique_push($unique_compiler_data, $result_json['compiler-options']);
+				}
+			}
+			// report against graph with $graph->addTestNote($note, $hover_title = null);
+		}
+
+		if(empty($json))
+		{
+			// no JSON data being reported to look at...
+			return false;
+		}
+
+		$compiler_options_string = '(' . strtoupper($unique_compiler_data[0]['compiler-type']) . ') ' . $unique_compiler_data[0]['compiler'] . ' options: ';
+
+		switch(count($unique_compiler_data))
+		{
+			case 0:
+				break;
+			case 1:
+				if($unique_compiler_data[0]['compiler-options'] != null)
+				{
+					$graph->addTestNote($compiler_options_string . $unique_compiler_data[0]['compiler-options'], $unique_compiler_data[0]['compiler-options']);
+				}
+				break;
+			default:
+				$diff = call_user_func_array('array_diff_assoc', $unique_compiler_data);
+
+				if(count($diff) == 1)
+				{
+					$key = array_keys($diff);
+					$key = array_pop($key);
+				}
+
+				if(isset($diff[$key]))
+				{
+					$unique_compiler_data = array();
+					foreach($json as $identifier => &$data)
+					{
+						if(isset($data['compiler-options'][$key]))
+						{
+							pts_arrays::unique_push($unique_compiler_data, explode(' ', $data['compiler-options'][$key]));
+						}
+					}
+
+					if(($c0 = count($unique_compiler_data[0])) < ($c1 = count($unique_compiler_data[1])))
+					{
+						for($i = 0; $i < ($c1 - $c0); $i++)
+						{
+							// Make the length of the first array the same length
+							array_push($unique_compiler_data[0], null);
+						}
+					}
+
+					$diff = call_user_func_array('array_diff', $unique_compiler_data);
+
+					if(count($diff) == 1)
+					{
+						$diff = array_search(array_pop($diff), $unique_compiler_data[0]);
+
+						if($diff !== false)
+						{
+							if($key == 'compiler-options')
+							{
+								$intersect = call_user_func_array('array_intersect', $unique_compiler_data);
+								$graph->addTestNote($compiler_options_string . implode(' ', $intersect));
+							}
+
+							foreach($json as $identifier => &$data)
+							{
+								if(isset($data['compiler-options'][$key]))
+								{
+									$options = explode(' ', $data['compiler-options'][$key]);
+
+									if(isset($options[$diff]) && stripos($identifier, $options[$diff]) === false)
+									{
+										$graph->addGraphIdentifierNote($identifier, $options[$diff]);
+									}
+								}
+							}
+						}
+					}
+				}
+				break;
+		}
+	}
 	public static function evaluate_redundant_identifier_words($identifiers)
 	{
 		if(count($identifiers) < 6)
@@ -505,8 +640,9 @@ class pts_render
 
 		return $test_result;
 	}
-	public static function compact_result_file_test_object(&$mto, &$result_table = false, $identifiers_inverted = false, $extra_attributes = null)
+	public static function compact_result_file_test_object(&$mto, &$result_table = false, &$result_file, $extra_attributes = null)
 	{
+		$identifiers_inverted = $result_file && $result_file->is_multi_way_inverted();
 		// TODO: this may need to be cleaned up, its logic is rather messy
 		$condense_multi_way = isset($extra_attributes['condense_multi_way']);
 		if(count($mto->test_profile->get_result_scale_offset()) > 0)
@@ -521,6 +657,7 @@ class pts_render
 		$prev_date = null;
 		$is_tracking = true;
 		$sha1_short_count = 0;
+		$buffer_count = $mto->test_result_buffer->get_count();
 
 		if($identifiers_inverted)
 		{
@@ -535,7 +672,7 @@ class pts_render
 
 		foreach($mto->test_result_buffer->get_buffer_items() as $buffer_item)
 		{
-			$identifier = pts_strings::trim_explode(':', $buffer_item->get_result_identifier());
+			$identifier = array_map('trim', explode(':', $buffer_item->get_result_identifier()));
 
 			switch(count($identifier))
 			{
@@ -572,7 +709,7 @@ class pts_render
 					}
 
 					// Check to see if only numeric changes are being made
-					$sha1_short_hash_ending = isset($date[7]) && pts_strings::string_only_contains(substr($date, -8), pts_strings::CHAR_NUMERIC | pts_strings::CHAR_LETTER);
+					$sha1_short_hash_ending = isset($date[7]) && ctype_alnum(substr($date, -8));
 					$date = str_replace('s', null, pts_strings::remove_from_string($date, pts_strings::CHAR_NUMERIC | pts_strings::CHAR_DASH | pts_strings::CHAR_DECIMAL));
 
 					if($sha1_short_hash_ending)
@@ -590,6 +727,12 @@ class pts_render
 			}
 		}
 
+		if($is_tracking == false && $sha1_short_count > 5)
+		{
+			// It's probably actually tracking..... based upon Stefan's Wine 1.4 example on 15 March 2012
+			$is_tracking = true;
+		}
+
 		foreach(array_keys($days) as $day_key)
 		{
 			$days[$day_key] = $systems;
@@ -599,7 +742,7 @@ class pts_render
 
 		foreach($mto->test_result_buffer->get_buffer_items() as $buffer_item)
 		{
-			$identifier = pts_strings::trim_explode(':', $buffer_item->get_result_identifier());
+			$identifier = array_map('trim', explode(':', $buffer_item->get_result_identifier()));
 
 			switch(count($identifier))
 			{
@@ -649,6 +792,12 @@ class pts_render
 		{
 			$mto->test_profile->set_result_scale($mto->test_profile->get_result_scale() . ' | ' . implode(',', array_keys($days)));
 
+			if($is_tracking && $buffer_count < 16 && $result_file && pts_result_file_analyzer::analyze_result_file_intent($result_file) != false)
+			{
+				// It can't be a tracker if the result file is comparing hardware/software, etc
+				$is_tracking = false;
+			}
+
 			switch($mto->test_profile->get_display_format())
 			{
 				//case 'HORIZONTAL_BOX_PLOT':
@@ -709,7 +858,7 @@ class pts_render
 
 		foreach($identifiers as $identifier)
 		{
-			$identifier_r = pts_strings::trim_explode(':', $identifier);
+			$identifier_r = explode(':', $identifier);
 
 			if(count($identifier_r) != 2 || (isset($identifier[14]) && $identifier[4] == '-' && $identifier[13] == ':'))
 			{
@@ -800,6 +949,101 @@ class pts_render
 
 		return $is_multi_way ? array($is_multi_way, $is_multi_way_inverted) : false;
 	}
+	public static function renderer_compatibility_check($user_agent)
+	{
+		$user_agent .= ' ';
+		$selected_renderer = 'SVG';
+
+		// Yahoo Slurp, msnbot, and googlebot should always be served SVG so no problems there
+
+		if(($p = strpos($user_agent, 'Gecko/')) !== false)
+		{
+			// Mozilla Gecko-based browser (Firefox, etc)
+			$gecko_date = substr($user_agent, ($p + 6));
+			$gecko_date = substr($gecko_date, 0, 6);
+
+			// Around Firefox 3.0 era is best
+			// Firefox 2.0 mostly works except text might not show...
+			if($gecko_date < 200702)
+			{
+				$selected_renderer = 'PNG';
+			}
+		}
+		else if(($p = strpos($user_agent, 'AppleWebKit/')) !== false)
+		{
+			// Safari, Google Chrome, Google Chromium, etc
+			$webkit_ver = substr($user_agent, ($p + 12));
+			$webkit_ver = substr($webkit_ver, 0, strpos($webkit_ver, ' '));
+
+			// Webkit 532.2 534.6 (WebOS 3.0.2) on WebOS is buggy for SVG
+			// iPhone OS is using 533 right now
+			if($webkit_ver < 533 || strpos($user_agent, 'hpwOS') !== false)
+			{
+				$selected_renderer = 'PNG';
+			}
+
+			if(($p = strpos($user_agent, 'Android ')) !== false)
+			{
+				$android_ver = substr($user_agent, ($p + 8), 3);
+
+				// Android browser doesn't support SVG.
+				// Google bug report 1376 for Android - http://code.google.com/p/android/issues/detail?id=1376
+				// Looks like it might work though in 3.0 Honeycomb
+				if($android_ver < 3.0)
+				{
+					$selected_renderer = 'PNG';
+				}
+			}
+		}
+		else if(($p = strpos($user_agent, 'Opera/')) !== false)
+		{
+			// Opera
+			$ver = substr($user_agent, ($p + 6));
+			$ver = substr($ver, 0, strpos($ver, ' '));
+
+			// 9.27, 9.64 displays most everything okay
+			if($ver < 9.27)
+			{
+				$selected_renderer = 'PNG';
+			}
+
+			// text-alignment is still fucked as of 11.50/12.0
+			$selected_renderer = 'PNG';
+		}
+		else if(($p = strpos($user_agent, 'Epiphany/')) !== false)
+		{
+			// Older versions of Epiphany. Newer versions should report their Gecko or WebKit appropriately
+			$ver = substr($user_agent, ($p + 9));
+			$ver = substr($ver, 0, 4);
+
+			if($ver < 2.22)
+			{
+				$selected_renderer = 'PNG';
+			}
+		}
+		else if(($p = strpos($user_agent, 'KHTML/')) !== false)
+		{
+			// KDE Konqueror as of 4.7 is still broken for SVG
+			$selected_renderer = 'PNG';
+		}
+		else if(($p = strpos($user_agent, 'MSIE ')) !== false)
+		{
+			$ver = substr($user_agent, ($p + 5), 1);
+
+			// Microsoft Internet Explorer 9.0 finally seems to do SVG right
+			if($ver < 10 && $ver != 1)
+			{
+				$selected_renderer = 'PNG';
+			}
+		}
+		else if(strpos($user_agent, 'facebook') !== false)
+		{
+			// Facebook uses this string for its Like/Share crawler, so serve it a PNG so it can use it as an image
+			$selected_renderer = 'PNG';
+		}
+
+		return $selected_renderer;
+	}
 }
 
 ?>
