@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010 - 2011, Phoronix Media
-	Copyright (C) 2010 - 2011, Michael Larabel
+	Copyright (C) 2010 - 2012, Phoronix Media
+	Copyright (C) 2010 - 2012, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -81,7 +81,7 @@ class pts_result_file_analyzer
 			pts_result_file_analyzer::system_components_to_table($data, $identifiers, $rows, $hw);
 			pts_result_file_analyzer::system_components_to_table($data, $identifiers, $rows, $sw);
 			pts_result_file_analyzer::compact_result_table_data($data, $identifiers, true);
-			$desc = pts_result_file_analyzer::analyze_system_component_changes($data, $rows, array(array('Graphics', 'Monitor', 'Display Driver', 'OpenGL'), array('Graphics', 'Display Driver', 'OpenGL'), array('Graphics', 'OpenGL'), array('Graphics', 'Display Driver')), $return_all_changed_indexes);
+			$desc = pts_result_file_analyzer::analyze_system_component_changes($data, $rows, array(array('Graphics', 'Monitor', 'Display Driver', 'OpenGL'), array('Graphics', 'Display Driver', 'OpenGL'), array('Graphics', 'OpenGL'), array('Graphics', 'Kernel'), array('Graphics', 'Display Driver')), $return_all_changed_indexes);
 		}
 
 		if($desc)
@@ -157,8 +157,13 @@ class pts_result_file_analyzer
 
 			if(count($changed_indexes) <= $max_combo_count)
 			{
-				while($comparison_good && ($this_identifier = array_shift($data)) != null)
+				while($comparison_good && ($this_identifier = array_shift($data)) !== null)
 				{
+					if(empty($this_identifier))
+					{
+						continue;
+					}
+
 					$this_keys = array_keys($this_identifier);
 					$do_push = false;
 
@@ -364,63 +369,6 @@ class pts_result_file_analyzer
 			$c_index++;
 		}
 	}
-	public static function result_file_to_csv(&$result_file)
-	{
-		$csv_output = null;
-		$delimiter = ',';
-
-		$csv_output .= $result_file->get_title() . PHP_EOL . PHP_EOL;
-
-		$columns = $result_file->get_system_identifiers();
-		$rows = array();
-		$table_data = array();
-
-		pts_result_file_analyzer::system_components_to_table($table_data, $columns, $rows, $result_file->get_system_hardware());
-		pts_result_file_analyzer::system_components_to_table($table_data, $columns, $rows, $result_file->get_system_software());
-
-		$csv_output .= ' ';
-
-		foreach($columns as $column)
-		{
-			$csv_output .= $delimiter . '"' . $column . '"';
-		}
-		$csv_output .= PHP_EOL;
-
-		foreach($rows as $i => $row)
-		{
-			$csv_output .= $row;
-
-			foreach($columns as $column)
-			{
-				$csv_output .= $delimiter . $table_data[$column][$i];
-			}
-
-			$csv_output .= PHP_EOL;
-		}
-
-		$csv_output .= PHP_EOL;
-		$csv_output .= ' ';
-
-		foreach($columns as $column)
-		{
-			$csv_output .= $delimiter . '"' . $column . '"';
-		}
-		$csv_output .= PHP_EOL;
-
-		foreach($result_file->get_result_objects() as $result_object)
-		{
-			$csv_output .= '"' . $result_object->test_profile->get_title() . ' - ' . $result_object->get_arguments_description() . '"';
-
-			foreach($result_object->test_result_buffer->get_values() as $value)
-			{
-				$csv_output .= $delimiter . $value;
-			}
-			$csv_output .= PHP_EOL;
-		}
-		$csv_output .= PHP_EOL;
-
-		return $csv_output;
-	}
 }
 
 ?>
