@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 	phoronix-test-suite.php: The main code for initalizing the Phoronix Test Suite
 
 	This program is free software; you can redistribute it and/or modify
@@ -21,10 +21,7 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-if(defined('LC_NUMERIC'))
-{
-	setlocale(LC_NUMERIC, 'C');
-}
+setlocale(LC_NUMERIC, 'C');
 define('PTS_PATH', dirname(dirname(__FILE__)) . '/');
 
 // PTS_MODE types
@@ -44,9 +41,25 @@ if(!PTS_IS_CLIENT)
 	return;
 }
 
+// Default to C locale
+setlocale(LC_ALL, 'C');
+
 if(ini_get('date.timezone') == null)
 {
-	date_default_timezone_set('UTC');
+	$tz = null;
+
+	// timezone_name_from_abbr was added in PHP 5.1.3. pre-5.2 really isn't supported by PTS, but don't at least error out here but let it get to proper checks...
+	if(is_executable('/bin/date') && function_exists('timezone_name_from_abbr'))
+	{
+		$tz = timezone_name_from_abbr(trim(shell_exec('date +%Z 2> /dev/null')));
+	}
+
+	if($tz == null || !in_array($tz, timezone_identifiers_list()))
+	{
+		$tz = 'UTC';
+	}
+
+	date_default_timezone_set($tz);
 }
 
 if(ini_get('open_basedir') != false)
