@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2011, Phoronix Media
-	Copyright (C) 2008 - 2011, Michael Larabel
+	Copyright (C) 2008 - 2012, Phoronix Media
+	Copyright (C) 2008 - 2012, Michael Larabel
 	pts-core.php: To boot-strap the Phoronix Test Suite start-up
 
 	This program is free software; you can redistribute it and/or modify
@@ -21,21 +21,26 @@
 	along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-define('PTS_VERSION', '3.6.1');
-define('PTS_CORE_VERSION', 3610);
-define('PTS_CODENAME', 'ARENDAL');
+define('PTS_VERSION', '3.8.0');
+define('PTS_CORE_VERSION', 3800);
+define('PTS_CODENAME', 'BYGLAND');
 define('PTS_IS_CLIENT', (defined('PTS_MODE') && PTS_MODE == 'CLIENT'));
 define('PTS_IS_DEV_BUILD', (substr(PTS_VERSION, -2, 1) == 'm'));
 
+if(!defined('PTS_PATH'))
+{
+	define('PTS_PATH', dirname(dirname(__FILE__)) . '/');
+}
+
 function pts_codename($full_string = false)
 {
 	$codename = ucwords(strtolower(PTS_CODENAME));
 
 	return ($full_string ? 'PhoronixTestSuite/' : null) . $codename;
 }
-function pts_title($show_both = false)
+function pts_title($show_codename = false)
 {
-	return 'Phoronix Test Suite' . (PTS_VERSION != null ? ' v' . PTS_VERSION : null) . (PTS_CODENAME != null && (PTS_VERSION == null || $show_both ) ? ' (' . ucwords(strtolower(PTS_CODENAME)) . ')' : null);
+	return 'Phoronix Test Suite v' . PTS_VERSION . ($show_codename ? ' (' . pts_codename() . ')' : null);
 }
 function pts_define_directories()
 {
@@ -47,34 +52,30 @@ function pts_define_directories()
 		define('PTS_USER_PATH', pts_client::user_home_directory() . '.phoronix-test-suite/');
 		define('PTS_CORE_STORAGE', PTS_USER_PATH . 'core.pt2so');
 		define('PTS_TEMP_STORAGE', PTS_USER_PATH . 'temp.pt2so');
+		define('PTS_MODULE_LOCAL_PATH', PTS_USER_PATH . 'modules/');
+		define('PTS_MODULE_DATA_PATH', PTS_USER_PATH . 'modules-data/');
+		define('PTS_DOWNLOAD_CACHE_PATH', PTS_USER_PATH . 'download-cache/');
+		define('PTS_OPENBENCHMARKING_SCRATCH_PATH', PTS_USER_PATH . 'openbenchmarking.org/');
+		define('PTS_TEST_PROFILE_PATH', PTS_USER_PATH . 'test-profiles/');
+		define('PTS_TEST_SUITE_PATH', PTS_USER_PATH . 'test-suites/');
+		define('PTS_RESULTS_VIEWER_PATH', PTS_CORE_PATH . 'results-viewer/');
 	}
 
 	// Misc Locations
 	define('PTS_MODULE_PATH', PTS_CORE_PATH . 'modules/');
-	define('PTS_MODULE_LOCAL_PATH', PTS_USER_PATH . 'modules/');
-	define('PTS_MODULE_DATA_PATH', PTS_USER_PATH . 'modules-data/');
-	define('PTS_DOWNLOAD_CACHE_PATH', PTS_USER_PATH . 'download-cache/');
 	define('PTS_CORE_STATIC_PATH', PTS_CORE_PATH . 'static/');
 	define('PTS_COMMAND_PATH', PTS_CORE_PATH . 'commands/');
 	define('PTS_EXDEP_PATH', PTS_CORE_PATH . 'external-test-dependencies/');
-	define('PTS_RESULTS_VIEWER_PATH', PTS_CORE_PATH . 'results-viewer/');
 	define('PTS_OPENBENCHMARKING_PATH', PTS_CORE_PATH . 'openbenchmarking.org/');
-	define('PTS_OPENBENCHMARKING_SCRATCH_PATH', PTS_USER_PATH . 'openbenchmarking.org/');
-
-	// Test & Suite Locations
-	define('PTS_TEST_PROFILE_PATH', PTS_USER_PATH . 'test-profiles/');
-	define('PTS_TEST_SUITE_PATH', PTS_USER_PATH . 'test-suites/');
 }
 function pts_needed_extensions()
 {
 	return array(
 		// Required? - The Check If In Place - Name - Description
-
 		// Required extesnions denoted by 1 at [0]
 		array(1, extension_loaded('dom'), 'DOM', 'The PHP Document Object Model (DOM) is required for XML operations.'),
 		array(1, extension_loaded('zip') || extension_loaded('zlib'), 'ZIP', 'PHP Zip support is required for file compression and decompression.'),
 		array(1, function_exists('json_decode'), 'JSON', 'PHP JSON support is required for OpenBenchmarking.org communication.'),
-
 		// Optional but recommended extensions
 		array(0, extension_loaded('openssl'), 'OpenSSL', 'PHP OpenSSL support is recommended to support HTTPS traffic.'),
 		array(0, extension_loaded('gd'), 'GD', 'The PHP GD library is recommended for improved graph rendering.'),
@@ -96,8 +97,9 @@ if(PTS_IS_CLIENT || defined('PTS_AUTO_LOAD_OBJECTS'))
 			{
 				if($file != '.' && $file != '..')
 				{
-					if(is_dir($dir . '/' . $file))
+					if(is_dir($dir . '/' . $file) && (PTS_IS_CLIENT || $file != 'client'))
 					{
+						// The client folder should contain classes exclusively used by the client
 						pts_build_dir_php_list($dir . '/' . $file, $files);
 					}
 					else if(substr($file, -4) == '.php')
@@ -107,7 +109,6 @@ if(PTS_IS_CLIENT || defined('PTS_AUTO_LOAD_OBJECTS'))
 				}
 			}
 		}
-
 		closedir($dh);
 	}
 	function __autoload($to_load)
